class FlowTask < ActiveRecord::Base

  belongs_to :user

  # Input resources for the task, can be any model instance or file attachment
  has_many :inputs, :class_name => "FlowTaskInput", :dependent => :destroy, :inverse_of => :flow_task

  # Output resources, generated by run method below
  has_many :outputs, :class_name => "FlowTaskOutput", :dependent => :destroy, :inverse_of => :flow_task

  accepts_nested_attributes_for :inputs, :outputs

  # validates_presence_of :inputs
  serialize :options

  # to be used as the friendly URL
  def to_param
    "#{id}-#{self.class.to_s.underscore}"
  end

  def status
    if error_msg.present?
      "error"
    elsif finished_at.present?
      "done"
    elsif started_at.present?
      "working"
    else
      "start"
    end
  end

  # Runs a system command with logging, captures STDIN, STDOUT, and STDERR and returns them
  def run_command(cmd)
    require 'open3'
    Rails.logger.info "[INFO #{Time.now}] #{self} running #{cmd}"
    update_attribute(:command, cmd)
    stdin, stdout, stderr = Open3.popen3(cmd)
    [stdin, stdout, stderr].map do |io|
      s = io.read.strip rescue nil
      io.close
      s
    end
  end

end
